/*
 * Copyright 2007 Sun Microsystems, Inc.
 * All rights reserved.  You may not modify, use,
 * reproduce, or distribute this software except in
 * compliance with  the terms of the License at:
 * http://developer.sun.com/berkeley_license.html
 */


package cart.secure.ejb;

import java.util.ArrayList;
import java.util.List;
import javax.ejb.Remove;
import javax.ejb.SessionContext;
import javax.ejb.Stateful;
import javax.annotation.Resource;
import javax.annotation.security.RolesAllowed;
import javax.annotation.security.PermitAll;
import org.jboss.ejb3.annotation.SecurityDomain;




@Stateful
@SecurityDomain("MySqlDbRealm")
public class CartBean implements Cart {
    List<String> contents;
    String customerId;
    String customerName;
    @Resource
    SessionContext ctx;
  

    public void initialize(String person) throws BookException {
       
        if (person == null) {
            throw new BookException("Null person not allowed.");
        } else {
            customerName = person;
        }
        System.out.println(ctx.getCallerPrincipal());
        
        customerId = "0";
        contents = new ArrayList<String>();
        
        
        
    }

    public void initialize(
    	   
        String person,
        String id) throws BookException {
    	System.out.println(ctx.getCallerPrincipal());
        if (person == null) {
            throw new BookException("Null person not allowed.");
        } else {
            customerName = person;
        }

        IdVerifier idChecker = new IdVerifier();

        if (idChecker.validate(id)) {
            customerId = id;
        } else {
            throw new BookException("Invalid id: " + id);
        }

        contents = new ArrayList<String>();
        
    }

    @RolesAllowed("CartUser")
    public void addBook(String title) {
        contents.add(title);
   
    }

    @RolesAllowed("CartUser")
    public void removeBook(String title) throws BookException {
        boolean result = contents.remove(title);

        if (result == false) {
            throw new BookException("\"" + title + "\" not in cart.");
        }
    }

    @RolesAllowed("CartUser")
    public List<String> getContents() {
        return contents;
    }

    @Remove()
    public void remove() {
        contents = null;
    }
}
